@@ -13,9 +13,9 @@
 
 """
 
-from .collect import Collect
+from .collect import Collect # noqa
 
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
 __project__ = __name__
-__version__ = "0.2.3"
+__version__ = "1.0.4"
